@@ -8,7 +8,7 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '1.69'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -88,12 +88,6 @@ pod_coverage:
   # for either Class or method.
   private: []
 
-unused_vars:
-  skip: 0
-  global:
-    ignore_vars: []
-  module: {}
-
 EOF
   }
 
@@ -200,7 +194,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 1.69
+version 1.70
 
 =head1 SYNOPSIS
 
